@@ -1,4 +1,4 @@
 from __future__ import unicode_literals
 from netmiko.checkpoint.checkpoint_gaia_ssh import CheckPointGaiaSSH
 
-__all__ = ['CheckPointGaiaSSH']
+__all__ = ["CheckPointGaiaSSH"]
