@@ -2,4 +2,4 @@ from __future__ import unicode_literals
 from netmiko.hp.hp_procurve import HPProcurveSSH, HPProcurveTelnet
 from netmiko.hp.hp_comware import HPComwareSSH, HPComwareTelnet
 
-__all__ = ['HPProcurveSSH', 'HPProcurveTelnet', 'HPComwareSSH', 'HPComwareTelnet']
+__all__ = ["HPProcurveSSH", "HPProcurveTelnet", "HPComwareSSH", "HPComwareTelnet"]
