@@ -1,3 +1,3 @@
 from netmiko.coriant.coriant_ssh import CoriantSSH
 
-__all__ = ['CoriantSSH']
+__all__ = ["CoriantSSH"]
