@@ -14,6 +14,7 @@ class SSHClient_noauth(SSHClient):
 
 class DellPowerConnectBase(CiscoBaseConnection):
     """Dell PowerConnect Driver."""
+
     def session_preparation(self):
         """Prepare the session after the connection has been established."""
         self.ansi_escape_codes = True
@@ -22,27 +23,33 @@ class DellPowerConnectBase(CiscoBaseConnection):
         self.enable()
         self.disable_paging(command="terminal datadump")
         # Clear the read buffer
-        time.sleep(.3 * self.global_delay_factor)
+        time.sleep(0.3 * self.global_delay_factor)
         self.clear_buffer()
 
-    def set_base_prompt(self, pri_prompt_terminator='>', alt_prompt_terminator='#',
-                        delay_factor=1):
+    def set_base_prompt(
+        self, pri_prompt_terminator=">", alt_prompt_terminator="#", delay_factor=1
+    ):
         """Sets self.base_prompt: used as delimiter for stripping of trailing prompt in output."""
         prompt = super(DellPowerConnectBase, self).set_base_prompt(
-                pri_prompt_terminator=pri_prompt_terminator,
-                alt_prompt_terminator=alt_prompt_terminator,
-                delay_factor=delay_factor)
+            pri_prompt_terminator=pri_prompt_terminator,
+            alt_prompt_terminator=alt_prompt_terminator,
+            delay_factor=delay_factor,
+        )
         prompt = prompt.strip()
         self.base_prompt = prompt
         return self.base_prompt
 
-    def check_config_mode(self, check_string='(config)#'):
+    def check_config_mode(self, check_string="(config)#"):
         """Checks if the device is in configuration mode"""
-        return super(DellPowerConnectBase, self).check_config_mode(check_string=check_string)
+        return super(DellPowerConnectBase, self).check_config_mode(
+            check_string=check_string
+        )
 
-    def config_mode(self, config_command='config'):
+    def config_mode(self, config_command="config"):
         """Enter configuration mode."""
-        return super(DellPowerConnectBase, self).config_mode(config_command=config_command)
+        return super(DellPowerConnectBase, self).config_mode(
+            config_command=config_command
+        )
 
 
 class DellPowerConnectSSH(DellPowerConnectBase):
@@ -51,6 +58,7 @@ class DellPowerConnectSSH(DellPowerConnectBase):
     To make it work, we have to override the SSHClient _auth method.
     If we use login/password, the ssh server use the (none) auth mechanism.
     """
+
     def _build_ssh_client(self):
         """Prepare for Paramiko SSH connection.
 
@@ -65,9 +73,9 @@ class DellPowerConnectSSH(DellPowerConnectBase):
 
         # Load host_keys for better SSH security
         if self.system_host_keys:
-                        remote_conn_pre.load_system_host_keys()
+            remote_conn_pre.load_system_host_keys()
         if self.alt_host_keys and path.isfile(self.alt_key_file):
-                        remote_conn_pre.load_host_keys(self.alt_key_file)
+            remote_conn_pre.load_host_keys(self.alt_key_file)
 
         # Default is to automatically add untrusted hosts (make sure appropriate for your env)
         remote_conn_pre.set_missing_host_key_policy(self.key_policy)
@@ -83,14 +91,14 @@ class DellPowerConnectSSH(DellPowerConnectBase):
         """
         delay_factor = self.select_delay_factor(delay_factor)
         i = 0
-        time.sleep(delay_factor * .5)
+        time.sleep(delay_factor * 0.5)
         output = ""
         while i <= 12:
             output = self.read_channel()
             if output:
-                if 'User Name:' in output:
+                if "User Name:" in output:
                     self.write_channel(self.username + self.RETURN)
-                elif 'Password:' in output:
+                elif "Password:" in output:
                     self.write_channel(self.password + self.RETURN)
                     break
                 time.sleep(delay_factor * 1)
@@ -102,4 +110,5 @@ class DellPowerConnectSSH(DellPowerConnectBase):
 
 class DellPowerConnectTelnet(DellPowerConnectBase):
     """Dell PowerConnect Telnet Driver."""
+
     pass
