@@ -1,4 +1,4 @@
 from __future__ import unicode_literals
 from netmiko.linux.linux_ssh import LinuxSSH, LinuxFileTransfer
 
-__all__ = ['LinuxSSH', 'LinuxFileTransfer']
+__all__ = ["LinuxSSH", "LinuxFileTransfer"]
